defaults = {
    'CONTENT_TYPE': 'application/json; charset=UTF-8',
    'DEFAULT_REQUEST_TIMEOUT': 180000,
    'MS_IN_A_DAY': 86400000,
    'MAX_REQUEST_TIMEOUT': 30,
    'MAX_LINE_LENGTH': 32000,
    'MAX_INPUT_LENGTH': 32,
    'FLUSH_INTERVAL': 5,
    'FLUSH_NOW': 1,
    'FLUSH_BYTE_LIMIT': 1000000,
    'LOGDNA_URL': 'https://logs.logdna.com/logs/ingest'
}
